==========================
Welcome to BioLM AI's Docs
==========================

.. grid:: 2

    .. grid-item-card::  All Models
       :margin: auto
       :text-align: center
       :link: model-docs-home
       :link-type: ref

       .. image:: _static/model_docs_icon.png
          :scale: 10 %
          :alt: alternate text

    .. grid-item-card::  API Reference
       :margin: auto
       :text-align: center
       :link: https://api.biolm.ai

       .. image:: _static/api_reference_icon.png
          :scale: 10 %
          :alt: alternate text

.. grid:: 2

    .. grid-item-card::  Python SDK
       :margin: auto
       :text-align: center
       :link: quickstart-sdk
       :link-type: ref

       .. image:: _static/python_sdk_icon.png
          :scale: 10 %
          :alt: alternate text

    .. grid-item-card::  Bio-Chat Agents
       :margin: auto
       :text-align: center
       :link: https://biolm.ai/ui/chat-agents/

       .. image:: _static/chat_agents_icon.png
          :scale: 10 %
          :alt: alternate text

.. grid:: 2

    .. grid-item-card::  Jupyter Notebooks
       :margin: auto
       :text-align: center
       :link: https://jupyter.biolm.ai/lab?path=0_Introduction.ipynb

       .. image:: _static/jupyter_notebooks_icon.png
          :scale: 10 %
          :alt: alternate text

    .. grid-item-card::  Back to BioLM
       :margin: auto
       :text-align: center
       :link: https://biolm.ai

       .. image:: _static/tutorials_icon.png
          :scale: 10 %
          :alt: alternate text


.. toctree::
   :maxdepth: 2
   :caption: Documentation:
   :hidden:

   model-docs/esm2/index
   model-docs/esm1v/index
   model-docs/esmfold/index
   model-docs/esmif/index
   model-docs/biolmtox/index
   model-docs/progen2/index
   model-docs/ablang/index
   model-docs/proteinfer/index
   model-docs/protgpt2/index
   model-docs/dnabert/index
   model-docs/finetuning/index


.. toctree::
   :maxdepth: 2
   :caption: REST API:
   :hidden:

   api_docs/index

.. toctree::
   :maxdepth: 2
   :caption: Tutorials & Guides:
   :hidden:

   tutorials_use_cases/notebooks


.. toctree::
   :maxdepth: 2
   :caption: Python Client:
   :hidden:

   python-client/index
   python-client/usage.rst
   modules.rst


